@@ -45,6 +45,9 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
         )
         BUILD_NUMBER = pyproject["build-system"].get("build-number", 0)
         CONFIGURE_ARGS = pyproject["build-system"].get("configure-args", [])
+        TEST_CMD = pyproject["build-system"].get(
+            "test-cmd", ["cmake", "--build", "BUILD_DIR", "-t", "test"]
+        )
     DISTRIBUTION = CONF["name"].replace("-", "_")
 
     logging.info("build wheel")
@@ -68,7 +71,8 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     def run_tests():
         logging.info("test")
         test_env = cmeel_config.get_test_env()
-        check_call(["cmake", "--build", BUILD, "-t", "test"], env=test_env)
+        test_cmd = [i.replace("BUILD_DIR", str(BUILD)) for i in TEST_CMD]
+        check_call(test_cmd, env=test_env)
 
     if RUN_TESTS and not RUN_TESTS_AFTER_INSTALL:
         run_tests()
@@ -81,7 +85,9 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
 
     logging.info("fix relocatablization")
     for f in INSTALL.rglob("*.cmake"):
-        check_call(["sed", "-i", f"s|{INSTALL}|${{PACKAGE_PREFIX_DIR}}|g", str(f)])
+        check_call(["sed", "-i.old", f"s|{INSTALL}|${{PACKAGE_PREFIX_DIR}}|g", str(f)])
+    for f in INSTALL.rglob("*.cmake.old"):
+        f.unlink()
 
     logging.info("create dist-info")
 
